==> blesta-5.10.2.zip: blesta/language/cs_cz/logs.php <==
<?php
/**
 * Logs
 *
 * @package blesta
 * @subpackage blesta.language.cs_cz
 * @copyright Copyright (c) 2024, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['Logs.!error.end_date.format'] = 'Nesprávný formát koncového data.';
$lang['Logs.!error.start_date.format'] = 'Nesprávný formát počátečního data.';
$lang['Logs.!error.group.betweenlength'] = 'Skupina musí mít délku 1 až 32 znaků.';
$lang['Logs.!error.group.unique'] = 'ID a skupina úlohy cron již byly převzaty.';
$lang['Logs.!error.event.maxlength'] = 'Délka události nesmí překročit 32 znaků.';
$lang['Logs.!error.run_id.exists'] = 'Nesprávné ID úlohy cron.';
$lang['Logs.!error.last_name.empty'] = 'Příjmení nesmí být prázdné.';
$lang['Logs.!error.first_name.empty'] = 'Křestní jméno nesmí být prázdné.';
$lang['Logs.!error.account_id.empty'] = 'Chybějící ID účtu.';
$lang['Logs.!error.account_type.format'] = 'Neplatný typ účtu.';
$lang['Logs.!error.type.format'] = 'Nesprávný typ.';
$lang['Logs.!error.staff_id.empty'] = 'Chybějící ID zaměstnance.';
$lang['Logs.!error.date_changed.valid'] = 'Změněno neplatné datum.';
$lang['Logs.!error.by_user_id.exists'] = 'Neplatné podle ID uživatele.';
$lang['Logs.!error.fields.empty'] = 'Chybějící logovatelná pole.';
$lang['Logs.!error.client_id.exists'] = 'Neplatné ID klienta.';
$lang['Logs.!error.contact_id.empty'] = 'Chybějící ID kontaktu.';
$lang['Logs.!error.success.format'] = 'Neplatná hodnota úspěchu.';
$lang['Logs.!error.messenger_id.exists'] = 'Neplatné ID messengeru.';
$lang['Logs.!error.to_user_id.exists'] = 'Neplatné ID uživatele.';
$lang['Logs.!error.result.format'] = 'Výsledkem přihlášení musí být buď "úspěch", nebo "neúspěch".';
$lang['Logs.!error.user_log_exists.empty'] = 'Uživatel na dané IP adrese neexistuje.';
$lang['Logs.!error.ip_address.length'] = 'Délka IP adresy nesmí překročit 39 znaků.';
$lang['Logs.!error.ip_address.empty'] = 'Chybějící IP adresa.';
$lang['Logs.!error.user_id.empty'] = 'Chybějící ID uživatele.';
$lang['Logs.!error.group.maxlength'] = 'Délka skupiny nesmí překročit 8 znaků.';
$lang['Logs.!error.group.empty'] = 'Chybějící skupina.';
$lang['Logs.!error.status.format'] = 'Nesprávný typ stavu.';
$lang['Logs.!error.url.empty'] = 'Chybějící adresa URL.';
$lang['Logs.!error.direction.format'] = 'Nesprávný typ směru.';
$lang['Logs.!error.gateway_id.exists'] = 'Neplatné ID brány.';
$lang['Logs.!error.module_id.exists'] = 'Neplatné ID modulu.';
$lang['Logs.!error.staff_id.exists'] = 'Neplatné ID zaměstnance.';
$lang['Logs.!error.sent.length'] = 'Délka odeslaného textu nesmí přesáhnout 1 znak.';
$lang['Logs.!error.sent.format'] = 'Odeslané musí být číslo.';
$lang['Logs.!error.subject.empty'] = 'Chybějící předmět.';
$lang['Logs.!error.from_name.empty'] = 'Chybí název od.';
$lang['Logs.!error.from_address.empty'] = 'Chybí adresa from.';
$lang['Logs.!error.to_address.empty'] = 'Chybí a na adresu.';
$lang['Logs.!error.company_id.exists'] = 'Neplatné ID společnosti.';
$lang['Logs.!error.deletelog_datetime'] = 'Nesprávný formát data.';

==> blesta-5.11.4.zip: blesta/language/cs_cz/logs.php <==
<?php
/**
 * Logs
 *
 * @package blesta
 * @subpackage blesta.language.cs_cz
 * @copyright Copyright (c) 2025, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['Logs.!error.end_date.format'] = 'Nesprávný formát koncového data.';
$lang['Logs.!error.start_date.format'] = 'Nesprávný formát počátečního data.';
$lang['Logs.!error.group.betweenlength'] = 'Skupina musí mít délku 1 až 32 znaků.';
$lang['Logs.!error.group.unique'] = 'ID a skupina úlohy cron již byly převzaty.';
$lang['Logs.!error.event.maxlength'] = 'Délka události nesmí překročit 32 znaků.';
$lang['Logs.!error.run_id.exists'] = 'Nesprávné ID úlohy cron.';
$lang['Logs.!error.last_name.empty'] = 'Příjmení nesmí být prázdné.';
$lang['Logs.!error.first_name.empty'] = 'Křestní jméno nesmí být prázdné.';
$lang['Logs.!error.account_id.empty'] = 'Chybějící ID účtu.';
$lang['Logs.!error.account_type.format'] = 'Neplatný typ účtu.';
$lang['Logs.!error.type.format'] = 'Nesprávný typ.';
$lang['Logs.!error.staff_id.empty'] = 'Chybějící ID zaměstnance.';
$lang['Logs.!error.date_changed.valid'] = 'Změněno neplatné datum.';
$lang['Logs.!error.by_user_id.exists'] = 'Neplatné podle ID uživatele.';
$lang['Logs.!error.fields.empty'] = 'Chybějící logovatelná pole.';
$lang['Logs.!error.client_id.exists'] = 'Neplatné ID klienta.';
$lang['Logs.!error.contact_id.empty'] = 'Chybějící ID kontaktu.';
$lang['Logs.!error.success.format'] = 'Neplatná hodnota úspěchu.';
$lang['Logs.!error.messenger_id.exists'] = 'Neplatné ID messengeru.';
$lang['Logs.!error.to_user_id.exists'] = 'Neplatné ID uživatele.';
$lang['Logs.!error.result.format'] = 'Výsledkem přihlášení musí být buď "úspěch", nebo "neúspěch".';
$lang['Logs.!error.user_log_exists.empty'] = 'Uživatel na dané IP adrese neexistuje.';
$lang['Logs.!error.ip_address.length'] = 'Délka IP adresy nesmí překročit 39 znaků.';
$lang['Logs.!error.ip_address.empty'] = 'Chybějící IP adresa.';
$lang['Logs.!error.user_id.empty'] = 'Chybějící ID uživatele.';
$lang['Logs.!error.group.maxlength'] = 'Délka skupiny nesmí překročit 8 znaků.';
$lang['Logs.!error.group.empty'] = 'Chybějící skupina.';
$lang['Logs.!error.status.format'] = 'Nesprávný typ stavu.';
$lang['Logs.!error.url.empty'] = 'Chybějící adresa URL.';
$lang['Logs.!error.direction.format'] = 'Nesprávný typ směru.';
$lang['Logs.!error.gateway_id.exists'] = 'Neplatné ID brány.';
$lang['Logs.!error.module_id.exists'] = 'Neplatné ID modulu.';
$lang['Logs.!error.staff_id.exists'] = 'Neplatné ID zaměstnance.';
$lang['Logs.!error.sent.length'] = 'Délka odeslaného textu nesmí přesáhnout 1 znak.';
$lang['Logs.!error.sent.format'] = 'Odeslané musí být číslo.';
$lang['Logs.!error.subject.empty'] = 'Chybějící předmět.';
$lang['Logs.!error.from_name.empty'] = 'Chybí název od.';
$lang['Logs.!error.from_address.empty'] = 'Chybí adresa from.';
$lang['Logs.!error.to_address.empty'] = 'Chybí a na adresu.';
$lang['Logs.!error.company_id.exists'] = 'Neplatné ID společnosti.';
$lang['Logs.!error.deletelog_datetime'] = 'Nesprávný formát data.';
$lang['Logs.!error.new_service.format'] = 'Nová služba musí být pole.';
$lang['Logs.!error.old_service.format'] = 'Stará služba musí být pole.';
$lang['Logs.!error.transactions.exists'] = 'Jedna nebo více transakcí neexistuje.';
$lang['Logs.!error.transaction_id.format'] = 'Transakce musí být pole.';
$lang['Logs.!error.service_id.exists'] = 'Neplatné ID služby.';
